#include <stdlib.h>
#include <stdio.h>
#include "generator.h"
#include "libs.h"
#include "log.h"

/* Runs when a custom command line argument is found
 returns true if no furhter argument processing should be done */
int hook_custom_arg(const char *key, const char *value)
{
	return 0;
}


/* Runs before anything else */
int hook_preinit()
{
	no_autodetect_sys = 1;
	no_save_cache = 1;
	fn_log = NULL;
	return 0;
}

/* Runs after initialization */
int hook_postinit()
{
	return 0;
}

/* Runs after all arguments are read and parsed */
int hook_postarg()
{
	return 0;
}

/* Runs when things should be detected for the host system */
int hook_detect_host()
{
	return 0;
}

/* Runs when things should be detected for the target system */
int hook_detect_target()
{
	return 0;
}

void generator_callback(char *cmd, char *args)
{
	generator_emit_string("* generator_callback: '");
	generator_emit_string(cmd);
	generator_emit_string("' '");
	generator_emit_string(args == NULL ? "(null)" : args);
	generator_emit_char('\'');
}

/* Runs after detection hooks, should generate the output (Makefiles, etc.) */
int hook_generate()
{
	const char *infn, *outfn;

	infn  = getenv("GEN_INPUT");
	outfn = getenv("GEN_OUTPUT");

	if ((infn == NULL) || (outfn == NULL)) {
		fprintf(stderr, "Environmental variables GEN_INPUT and GEN_OUTPUT must be set before running this program\n");
		return 1;
	}
	else {
		generate(infn, outfn);
	}
	return 0;
}

/* Runs before everything is uninitialized */
void hook_preuninit()
{
}

/* Runs at the very end, when everything is already uninitialized */
void hook_postuninit()
{
}

